# -*- coding: utf-8 -*-
# Generated by Django 1.9.6 on 2016-05-23 11:42
from __future__ import unicode_literals

from django.conf import settings
import django.contrib.gis.db.models.fields
from django.core.files.storage import FileSystemStorage
from django.db import migrations, models
import django.db.models.deletion
import uuid


class PrivateFileSystemStorage(FileSystemStorage):
    def __init__(self, *args, **kwargs):
        if 'location' not in kwargs:
            import environ
            env = environ.Env()
            kwargs['location'] = env.str('DJANGO_PRIVATE_MEDIA_ROOT', default=str(settings.ROOT_DIR.path('..', 'private_media')))
        super().__init__(*args, **kwargs)


class Migration(migrations.Migration):
    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='BoundingGeometry',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
            ],
        ),
        migrations.CreateModel(
            name='Excerpt',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=128, verbose_name='name')),
                ('is_public', models.BooleanField(default=False, verbose_name='is public')),
                ('is_active', models.BooleanField(default=True, verbose_name='is active')),
            ],
        ),
        migrations.CreateModel(
            name='ExtractionOrder',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('state', models.IntegerField(default=1, verbose_name='state')),
                ('process_start_date', models.DateTimeField(null=True, verbose_name='process start date')),
                ('process_reference', models.CharField(blank=True, max_length=128, null=True, verbose_name='process reference')),
                ('excerpt', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='extraction_orders', to='excerptexport.Excerpt', verbose_name='excerpt')),
                ('orderer', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='extraction_orders', to=settings.AUTH_USER_MODEL, verbose_name='orderer')),
            ],
        ),
        migrations.CreateModel(
            name='OutputFile',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('mime_type', models.CharField(max_length=64, verbose_name='mime type')),
                ('file', models.FileField(blank=True, null=True, storage=PrivateFileSystemStorage(), upload_to='', verbose_name='file')),
                ('creation_date', models.DateTimeField(auto_now_add=True, verbose_name='create date')),
                ('deleted_on_filesystem', models.BooleanField(default=False, verbose_name='deleted on filesystem')),
                ('public_identifier', models.UUIDField(default=uuid.uuid4, verbose_name='public identifier')),
                ('extraction_order', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='output_files', to='excerptexport.ExtractionOrder', verbose_name='extraction order')),
                ('content_type', models.CharField(default='', max_length=64, verbose_name='content type')),
                ('file_extension', models.CharField(default='', max_length=64, verbose_name='file extension')),
            ],
        ),
        migrations.CreateModel(
            name='BBoxBoundingGeometry',
            fields=[
                ('boundinggeometry_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='excerptexport.BoundingGeometry')),
                ('south_west', django.contrib.gis.db.models.fields.PointField(srid=4326)),
                ('north_east', django.contrib.gis.db.models.fields.PointField(srid=4326)),
            ],
            bases=('excerptexport.boundinggeometry',),
        ),
        migrations.AddField(
            model_name='excerpt',
            name='bounding_geometry',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, to='excerptexport.BoundingGeometry', verbose_name='bounding geometry'),
        ),
        migrations.AddField(
            model_name='excerpt',
            name='owner',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='excerpts', to=settings.AUTH_USER_MODEL, verbose_name='owner'),
        ),
        migrations.CreateModel(
            name='OsmosisPolygonFilterBoundingGeometry',
            fields=[
                ('boundinggeometry_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='excerptexport.BoundingGeometry')),
                ('polygon_file', models.FileField(storage=PrivateFileSystemStorage(), upload_to='')),
            ],
            bases=('excerptexport.boundinggeometry',),
        ),
        migrations.RemoveField(
            model_name='extractionorder',
            name='process_reference',
        ),
        migrations.AddField(
            model_name='extractionorder',
            name='_extraction_configuration',
            field=models.TextField(blank=True, default='', null=True, verbose_name='extraction options'),
        ),
        migrations.AddField(
            model_name='extractionorder',
            name='process_id',
            field=models.TextField(blank=True, null=True, verbose_name='process link'),
        ),
        migrations.AddField(
            model_name='extractionorder',
            name='progress_url',
            field=models.URLField(blank=True, null=True, verbose_name='progress URL'),
        ),
        migrations.RemoveField(
            model_name='extractionorder',
            name='process_start_date',
        ),
        migrations.AddField(
            model_name='extractionorder',
            name='download_status',
            field=models.IntegerField(choices=[(0, 'unknown'), (1, 'downloading'), (2, 'received')], default=0, verbose_name='file status'),
        ),
        migrations.AddField(
            model_name='extractionorder',
            name='country_id',
            field=models.IntegerField(blank=True, null=True, verbose_name='country ID'),
        ),
        migrations.AlterField(
            model_name='extractionorder',
            name='excerpt',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='extraction_orders', to='excerptexport.Excerpt', verbose_name='excerpt'),
        ),
        migrations.AddField(
            model_name='extractionorder',
            name='process_start_time',
            field=models.DateTimeField(blank=True, null=True, verbose_name='process start time'),
        ),
    ]
